==> haskell-byte-order-0.1.3.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byte-order
version:              0.1.3.0
visibility:           public
id:                   byte-order-0.1.3.0-CxJm6IMjWH9HJH1YmveOdM
key:                  byte-order-0.1.3.0-CxJm6IMjWH9HJH1YmveOdM
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  15f9eeafdfcf37443b0f93a365a7d604
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.0.2/site-local/byte-order-0.1.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/byte-order-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.0-CxJm6IMjWH9HJH1YmveOdM
depends:
    base-4.15.1.0 primitive-0.7.4.0-8RUdbvjRYjOFHQ1vgzaS7Q
    primitive-unaligned-0.1.1.2-7ZzYrjZU7zz73taJ8v0Iof
    wide-word-0.1.5.0-5dZGssPNxi1CP5kLpFsGGe

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byte-order-0.1.3.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byte-order
version:              0.1.3.0
visibility:           public
id:                   byte-order-0.1.3.0-AqCUeYakH9L8HzHUJPtFop
key:                  byte-order-0.1.3.0-AqCUeYakH9L8HzHUJPtFop
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/andrewthad/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  db861e74cbcb6cbce1e76fb7f2827c43
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.0.2/site-local/byte-order-0.1.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/byte-order-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.0-AqCUeYakH9L8HzHUJPtFop
depends:
    base-4.15.1.0 primitive-0.7.4.0-8SmDsFCxSqgE7BzeiM7pZ4
    primitive-unaligned-0.1.1.2-FqcbZDkuHtV9RFSLSQyTcx
    wide-word-0.1.5.0-HXJEjrisHilCtgjzU1PM4n

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
